@@ -3,11 +3,11 @@ use strict;
 use warnings;
 
 package Mite::App::Command::init;
-use Mite::Miteception;
+use Mite::Miteception -all;
 extends qw(Mite::App::Command);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
+our $VERSION   = '0.005003';
 
 ##-
 
