@@ -3,10 +3,10 @@ use strict;
 use warnings;
 
 package Mite::MakeMaker;
-use Mite::Miteception;
+use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
+our $VERSION   = '0.005003';
 
 ##-
 
