@@ -5,64 +5,47 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
-
-my %constants;
-BEGIN {
-	%constants = (
-		rw        => 'rw',
-		rwp       => 'rwp',
-		ro        => 'ro',
-		true      => !!1,
-		false     => !!0,
-	);
-}
-
-use constant \%constants;
+our $VERSION   = '0.005003';
 
 use Import::Into;
 use Mite::Shim ();
-use Carp ();
-use Scalar::Util ();
 use Types::Standard ();
 use Types::Path::Tiny ();
 use Type::Params ();
-use feature ();
 
 sub import {
 	my $class = shift;
 	my %arg = map { lc($_) => 1 } @_;
 
+	my $kind = $arg{'-role'} ? 'role' : 'class';
+
 	for my $import ( $class->to_import( \%arg ) ) {
 		my ( $pkg, $args ) = @$import;
 		$pkg->import::into( 1, @{ $args || [] } );
 	}
 
-	no strict 'refs';
-	my $caller = caller;
-	*{"$caller\::$_"} = \&{$_} for $class->constant_names;
+	my ( $caller, $file ) = caller;
 
-	return if $arg{'-basic'};
-
-	unshift @_, $class;
-	goto \&load_mite_file;
-}
-
-sub constant_names {
-	my $class = shift;
-	return keys %constants;
+	if ( $ENV{MITE_LIMITED_PARSING} ) {
+		require Mite::Project;
+		Mite::Project->default->inject_mite_functions(
+			 package     => $caller,
+			 file        => $file,
+			 arg         => \%arg,
+			 kind        => $kind,
+			 shim        => 'Mite::Shim',
+		);
+	}
+	else {
+		unshift @_, $class;
+		goto \&load_mite_file;
+	}
 }
 
 sub to_import {
 	my ( $class, $arg ) = ( shift, @_ );
 	no warnings 'uninitialized';
 	return (
-		[ 'Carp' => [
-			qw( carp croak confess ),
-		] ],
-		[ 'Scalar::Util' => [
-			qw( blessed ),
-		] ],
 		[ 'Types::Standard' => [
 			qw( -types slurpy ),
 		] ],
@@ -73,9 +56,6 @@ sub to_import {
 			compile           => { -as => 'sig_pos'   },
 			compile_named_oo  => { -as => 'sig_named' },
 		] ],
-		[ 'feature' => [
-			':5.10',
-		] ],
 	);
 }
 
