@@ -3,10 +3,10 @@ use strict;
 use warnings;
 
 package Mite::Project;
-use Mite::Miteception;
+use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
+our $VERSION   = '0.005003';
 
 has sources =>
   is            => ro,
@@ -23,6 +23,21 @@ has config =>
       return $config;
   };
 
+has _limited_parsing =>
+  is            => rw,
+  isa           => Bool,
+  default       => false;
+
+has _module_fakeout_namespace =>
+  is            => rw,
+  isa           => Str,
+  predicate     => true;
+
+has debug =>
+  is            => rw,
+  isa           => Bool,
+  default       => false;
+
 ##-
 
 use Mite::Source;
@@ -80,17 +95,31 @@ my $parse_mm_args = sub {
 sub inject_mite_functions {
     state $sig = sig_named(
         { head => [ Object ], named_to_list => true },
-        package => Any,
-        file    => Any,
-        kind    => Str,        { default => 'class' },
-        arg     => HashRef,    { default => {}      },
-        shim    => Str,
+        package   => Any,
+        file      => Any,
+        kind      => Str,        { default => 'class' },
+        arg       => HashRef,    { default => {}      },
+        shim      => Str,
+        x_source  => Optional[Object],
+        x_pkg     => Optional[Object],
     );
-    my ( $self, $package, $file, $kind, $arg, $shim ) = &$sig;
-    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $_[1]; };
+    my ( $self, $package, $file, $kind, $arg, $shim, $source, $pkg, $moresubs ) = &$sig;
+    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
 
-    my $source = $self->source_for( $file );
-    my $pkg    = $source->class_for( $package, $kind eq 'role' ? 'Mite::Role' : 'Mite::Class' );
+    my $fake_ns = $self->can('_module_fakeout_namespace') && $self->_module_fakeout_namespace;
+    if ( defined( $fake_ns ) and not $package =~ /^\Q$fake_ns/ ) {
+        $package = "$fake_ns\::$package";
+    }
+
+    warn "Inject functions into: $package\n" if $self->debug;
+
+    $source //= $self->source_for(
+        Path::Tiny::path( $ENV{MITE_LIMITED_PARSING} // $file )
+    );
+    $pkg    //= $source->class_for(
+        $package,
+        $kind eq 'role' ? 'Mite::Role' : 'Mite::Class',
+    );
     $pkg->shim_name( $shim );
 
     no strict 'refs';
@@ -128,29 +157,36 @@ sub inject_mite_functions {
 
     *{"$package\::param"} = sub {
         my ( $names, %spec ) = @_;
-        $spec{is} = 'ro' unless exists $spec{is};
-        $spec{required} = !!1 unless exists $spec{required};
+        $spec{is} = ro unless exists $spec{is};
+        $spec{required} = true unless exists $spec{required};
         $has->( $names, %spec );
     } if $requested->( param => 0 );
 
     *{"$package\::field"} = sub {
         my ( $names, %spec ) = @_;
-        $spec{is} ||= ( $spec{builder} || exists $spec{default} ) ? 'lazy' : 'rwp';
+        $spec{is} ||= ( $spec{builder} || exists $spec{default} ) ? lazy : rwp;
         $spec{init_arg} = undef unless exists $spec{init_arg};
         if ( defined $spec{init_arg} and $spec{init_arg} !~ /^_/ ) {
-            require Carp;
-            Carp::croak( "A defined 'field.init_arg' must begin with an underscore: " . $spec{init_arg} );
+            croak "A defined 'field.init_arg' must begin with an underscore: %s ", $spec{init_arg};
         }
         $has->( $names, %spec );
     } if $requested->( field => 0 );
 
     *{ $package .'::with' } = sub {
-        $pkg->add_roles_by_name( @_ );
+        $pkg->add_roles_by_name(
+            defined( $fake_ns )
+                ? ( map "$fake_ns\::$_", @_ )
+                : @_
+        );
         return;
     } if $requested->( 'with', 1 );
 
     *{ $package .'::extends' } = sub {
-        $pkg->superclasses( [ @_ ] );
+        $pkg->superclasses(
+            defined( $fake_ns )
+                ? [ map "$fake_ns\::$_", @_ ]
+                : [ @_ ]
+        );
         return;
     } if $kind eq 'class' && $requested->( 'extends', 1 );
 
@@ -162,11 +198,10 @@ sub inject_mite_functions {
     for my $modifier ( qw( before after around ) ) {
         *{ $package .'::'. $modifier } = sub {
             my ( $names, $coderef ) = &$parse_mm_args;
-            require Carp;
             CodeRef->check( $coderef )
-                or Carp::croak( "Expected a coderef method modifier" );
+                or croak "Expected a coderef method modifier";
             ArrayRef->of(Str)->check( $names ) && @$names
-                or Carp::croak( "Expected a list of method names to modify" );
+                or croak "Expected a list of method names to modify";
             $pkg->add_required_methods( @$names );
             return;
         } if $requested->( $modifier, 1 );
@@ -189,13 +224,28 @@ sub inject_mite_functions {
         *{"$package\::$f"} = \&{"$shim\::$f"};
         $pkg->imported_functions->{$f} = "$shim\::$f";
     }
+    if ( $requested->( blessed => false ) ) {
+        require Scalar::Util;
+        *{"$package\::blessed"} = \&Scalar::Util::blessed;
+        $pkg->imported_functions->{blessed} = "Scalar::Util::blessed";
+    }
+
+    if ( our %MORE_SUBS ) {
+        no warnings 'redefine';
+        for my $f ( keys %MORE_SUBS ) {
+            *{"$package\::$f"} = $MORE_SUBS{$f};
+        }
+    }
 }
 
 sub write_mites {
     my $self = shift;
 
     for my $source (values %{$self->sources}) {
-        $source->compiled->write;
+        warn "Write file: ${\ $source->compiled->file }\n" if $self->debug;
+        $source->compiled->write(
+            module_fakeout_namespace => $self->_module_fakeout_namespace,
+        );
     }
 
     return;
@@ -209,13 +259,43 @@ sub load_files {
     local @INC = @INC;
     unshift @INC, $inc_dir if defined $inc_dir;
     for my $file (@$files) {
-        my $pm_file = Path::Tiny::path($file)->relative($inc_dir);
-        require $pm_file;
+        $self->_load_file( $file, $inc_dir );
     }
 
     return;
 }
 
+sub _load_file {
+    my ( $self, $file, $inc_dir ) = @_;
+
+    warn "Load file: $file\n" if $self->debug;
+
+    $file = Path::Tiny::path($file);
+
+    if ( $self->_limited_parsing ) {
+        my $code = $file->slurp;
+        my ( $head, $tail ) = split '##-', $code;
+
+        if ( $self->_has__module_fakeout_namespace ) {
+            my $ns = $self->_module_fakeout_namespace;
+            $head =~ s/package /package $ns\::/;
+        }
+
+        do {
+            local $@;
+            local $ENV{MITE_LIMITED_PARSING} = "$file";
+            eval("$head; 1") or do die($@);
+        };
+
+        return;
+    }
+
+    my $pm_file = $file->relative($inc_dir);
+    require $pm_file;
+
+    return;
+}
+
 sub find_pms {
     my ( $self, $dir ) = ( shift, @_ );
     $dir //= $self->config->data->{source_from};
