@@ -3,11 +3,11 @@ use strict;
 use warnings;
 
 package Mite::Role::Tiny;
-use Mite::Miteception;
+use Mite::Miteception -all;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
+our $VERSION   = '0.005003';
 
 sub skip_compiling {
     return true;
