@@ -2,13 +2,10 @@ use 5.008001;
 use strict;
 use warnings;
 
-package Mite::Shim;
-
 # NOTE: Since the intention is to ship this file with a project, this file
 # cannot have any non-core dependencies.
 
-use strict;
-use warnings;
+package Mite::Shim;
 
 # Constants
 sub true  () { !!1 }
@@ -24,7 +21,7 @@ sub _error_handler {
     if ( @args ) {
         require Data::Dumper;
         local $Data::Dumper::Terse  = 1;
-        local $Data::Dumper::Indent = 1;
+        local $Data::Dumper::Indent = 0;
         $message = sprintf $message, map {
             ref($_) ? Data::Dumper::Dumper($_) : defined($_) ? $_ : '(undef)'
         } @args;
@@ -65,7 +62,7 @@ my $parse_mm_args = sub {
 };
 
 sub _is_compiling {
-    return $ENV{MITE_COMPILE} ? true : false;
+    return !! $ENV{MITE_COMPILE};
 }
 
 sub import {
@@ -90,14 +87,10 @@ sub import {
         );
     }
     else {
-        # Work around Test::Compile's tendency to 'use' modules.
-        # Mite.pm won't stand for that.
-        return if $ENV{TEST_COMPILE};
-
         # Changes to this filename must be coordinated with Mite::Compiled
         my $mite_file = $file . ".mite.pm";
         if( !-e $mite_file ) {
-            croak("Compiled Mite file ($mite_file) for $file is missing");
+            croak "Compiled Mite file ($mite_file) for $file is missing";
         }
 
         {
@@ -115,7 +108,7 @@ sub import {
 
 sub _inject_mite_functions {
     my ( $class, $caller, $file, $kind, $arg ) = ( shift, @_ );
-    my $requested = sub { $arg->{$_[0]} ? true : $arg->{'!'.$_[0]} ? false : $_[1]; };
+    my $requested = sub { $arg->{$_[0]} ? true : $arg->{'!'.$_[0]} ? false : $arg->{'-all'} ? true : $_[1]; };
 
     no strict 'refs';
     my $has = $class->_make_has( $caller, $file, $kind );
@@ -227,10 +220,10 @@ sub _make_with {
     my $get_orig = sub {
         my ( $caller, $name ) = @_;
 
-        my $orig = $caller->can($name);
+        my $orig = $caller->can( $name );
         return $orig if $orig;
 
-        croak( "Cannot modify method $name in $caller: no such method" );
+        croak "Cannot modify method $name in $caller: no such method";
     };
 
     sub before {
