@@ -3,13 +3,10 @@ use strict;
 use warnings;
 
 package Mite::Source;
-use Mite::Miteception;
+use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005002';
-
-use Mite::Compiled;
-use Mite::Class;
+our $VERSION   = '0.005003';
 
 has file =>
   is            => ro,
@@ -39,6 +36,9 @@ has project =>
 
 ##-
 
+use Mite::Compiled;
+use Mite::Class;
+
 sub has_class {
     my ( $self, $name ) = ( shift, @_ );
 
